tlslite.errors.TLSAlert

Package tlslite :: Module errors :: Class TLSAlert |
[show private | hide private]
[frames | no frames]

## Class TLSAlert

    Exception --+
                |
         TLSError --+
                    |
                   TLSAlert

Known Subclasses:
  `TLSLocalAlert`, `TLSRemoteAlert`

A TLS alert has been signalled.

Method Summary
Inherited from Exception
| ``__init__`(...)`
| ``__getitem__`(...)`
| ``__str__`(...)`

Class Variable Summary
`dict` | `_descriptionStr` = `{0: 'close_notify', 10: 'unexpected_me...`

Class Variable Details

    ### _descriptionStr Type: `dict` Value:
        {0: 'close_notify',
         10: 'unexpected_message',
         20: 'bad_record_mac',
         21: 'decryption_failed',
         22: 'record_overflow',
         30: 'decompression_failure',
         40: 'handshake_failure',
         41: 'no certificate',
        ...

Generated by Epydoc 2.0 on Mon Feb 21 21:56:55 2005 | http://epydoc.sf.net